@@ -1,4 +1,4 @@
-#
+
 # Package name and versioning information for ImageMagick.
 #
 # This file is sourced by a Bourne shell (/bin/sh) script so it must
@@ -7,22 +7,23 @@
 # Package base name
 PACKAGE_NAME='ImageMagick'
 
-#
-# Package version.  This is is the numeric version suffix applied to
-# PACKAGE_NAME (e.g. "1.0.0").
-PACKAGE_VERSION='6.7.8'
-PACKAGE_PERL_VERSION='6.78'
-PACKAGE_LIB_VERSION="0x678"
-PACKAGE_RELEASE="1"
-PACKAGE_LIB_VERSION_NUMBER="6,7,8,${PACKAGE_RELEASE}"
-PACKAGE_RELEASE_DATE=`date +%F`
-PACKAGE_STRING="$PACKAGE_NAME $PACKAGE_VERSION"
-
 #
 # Date of last ChangeLog update
 #
 PACKAGE_CHANGE_DATE=`awk '/^[0-9][0-9][0-9][0-9]-[0-9][0-9]-[0-9][0-9]/ { print substr($1,1,4) substr($1,6,2) substr($1,9,2); exit; }' ${srcdir}/ChangeLog`
 
+#
+# Package version.  This is is the numeric version suffix applied to
+# PACKAGE_NAME (e.g. "1.0.0").
+PACKAGE_VERSION='6.9.7'
+PACKAGE_PERL_VERSION='6.97'
+PACKAGE_LIB_VERSION="0x697"
+PACKAGE_RELEASE="5"
+PACKAGE_LIB_VERSION_NUMBER="6,9,7,${PACKAGE_RELEASE}"
+PACKAGE_RELEASE_DATE_RAW=`date +%F`
+PACKAGE_RELEASE_DATE_REPRODUCIBLE="${PACKAGE_CHANGE_DATE}"
+PACKAGE_STRING="$PACKAGE_NAME $PACKAGE_VERSION"
+
 #
 # Package version addendum.  This is an arbitrary suffix (if any) appended
 # to the package version. (e.g. "beta1")
@@ -35,6 +36,15 @@ PACKAGE_VERSION_ADDENDUM="-${PACKAGE_RELEASE}"
 # source and binary compatibility with older minor versions, and changes
 # in the PATCH level are perfectly compatible, forwards and backwards.
 # See http://apr.apache.org/versioning.html.
-MAGICK_LIBRARY_CURRENT=5
+#
+# PLEASE NOTE that doing a SO BUMP aka raising the CURRENT REVISION
+# could be avoided using libversioning aka map files.  You MUST change .map
+# files if you raise these versions.
+MAGICK_LIBRARY_CURRENT=3
 MAGICK_LIBRARY_REVISION=0
 MAGICK_LIBRARY_AGE=0
+
+# magick++
+MAGICKPP_LIBRARY_CURRENT=7
+MAGICKPP_LIBRARY_REVISION=0
+MAGICKPP_LIBRARY_AGE=0
