@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2017 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -15,16 +15,13 @@
 
   MAgickWand pixel wand private methods.
 */
-#ifndef _MAGICKWAND_PIXEL_WAND_PRIVATE_H
-#define _MAGICKWAND_PIXEL_WAND_PRIVATE_H
+#ifndef MAGICKWAND_PIXEL_WAND_PRIVATE_H
+#define MAGICKWAND_PIXEL_WAND_PRIVATE_H
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
 #endif
 
-extern WandExport void
-  PixelGetMagickColor(const PixelWand *,MagickPixelPacket *);
-
 #if defined(__cplusplus) || defined(c_plusplus)
 }
 #endif
